Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(439)

Unified Diff: runtime/vm/object.cc

Issue 1133713006: Deprecate 'dart:profiler' and move functionality to 'dart:developer' (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/method_recognizer.cc ('k') | runtime/vm/service.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/object.cc
diff --git a/runtime/vm/object.cc b/runtime/vm/object.cc
index 3d282a804b964d900abbe6582d2f2e3067731540..56d210d0db871ad60ae5210f7f0c6af7e82b4c6f 100644
--- a/runtime/vm/object.cc
+++ b/runtime/vm/object.cc
@@ -1223,19 +1223,19 @@ RawError* Object::Init(Isolate* isolate) {
RegisterPrivateClass(cls, Symbols::_LinkedHashMap(), lib);
pending_classes.Add(cls);
// Pre-register the profiler library so we can place the vm class
// UserTag there rather than the core library.
- lib = Library::LookupLibrary(Symbols::DartProfiler());
+ lib = Library::LookupLibrary(Symbols::DartDeveloper());
if (lib.IsNull()) {
- lib = Library::NewLibraryHelper(Symbols::DartProfiler(), true);
+ lib = Library::NewLibraryHelper(Symbols::DartDeveloper(), true);
lib.SetLoadRequested();
lib.Register();
- object_store->set_bootstrap_library(ObjectStore::kProfiler, lib);
+ object_store->set_bootstrap_library(ObjectStore::kDeveloper, lib);
}
ASSERT(!lib.IsNull());
- ASSERT(lib.raw() == Library::ProfilerLibrary());
+ ASSERT(lib.raw() == Library::DeveloperLibrary());
- lib = Library::LookupLibrary(Symbols::DartProfiler());
+ lib = Library::LookupLibrary(Symbols::DartDeveloper());
ASSERT(!lib.IsNull());
cls = Class::New<UserTag>();
RegisterPrivateClass(cls, Symbols::_UserTag(), lib);
@@ -10486,12 +10486,12 @@ void Library::CheckFunctionFingerprints() {
POLYMORPHIC_TARGET_LIST(CHECK_FINGERPRINTS);
all_libs.Clear();
- all_libs.Add(&Library::ZoneHandle(Library::MathLibrary()));
- MATH_LIB_INTRINSIC_LIST(CHECK_FINGERPRINTS);
+ all_libs.Add(&Library::ZoneHandle(Library::DeveloperLibrary()));
+ DEVELOPER_LIB_INTRINSIC_LIST(CHECK_FINGERPRINTS);
all_libs.Clear();
- all_libs.Add(&Library::ZoneHandle(Library::ProfilerLibrary()));
- PROFILER_LIB_INTRINSIC_LIST(CHECK_FINGERPRINTS);
+ all_libs.Add(&Library::ZoneHandle(Library::MathLibrary()));
+ MATH_LIB_INTRINSIC_LIST(CHECK_FINGERPRINTS);
all_libs.Clear();
all_libs.Add(&Library::ZoneHandle(Library::TypedDataLibrary()));
« no previous file with comments | « runtime/vm/method_recognizer.cc ('k') | runtime/vm/service.cc » ('j') | no next file with comments »
@@ -1223,19 +1223,19 @@ RawError* Object::Init(Isolate* isolate) {
RegisterPrivateClass(cls, Symbols::_LinkedHashMap(), lib);
pending_classes.Add(cls);
- // Pre-register the profiler library so we can place the vm class
+ // Pre-register the developer library so we can place the vm class
// UserTag there rather than the core library.

Powered by Google App Engine
This is Rietveld 408576698